shared_preferences_android library

Classes

AndroidSharedPreferencesStoreOptions
Options necessary for defining the use of the original SharedPreferences library.
SharedPreferencesAndroid
The Android implementation of SharedPreferencesStorePlatform.
SharedPreferencesAsyncAndroid
The Android implementation of SharedPreferencesAsyncPlatform.
SharedPreferencesAsyncAndroidOptions
Options for the Android specific SharedPreferences plugin.

Enums

SharedPreferencesAndroidBackendLibrary
Used to identify which Android library should be used on the backend of this call.