shared_preferences_android library
Classes
-
Options necessary for defining the use of the original
SharedPreferenceslibrary. -
The Android implementation of
SharedPreferencesStorePlatform. -
The Android implementation of
SharedPreferencesAsyncPlatform. - Options for the Android specific SharedPreferences plugin.
Enums
- Used to identify which Android library should be used on the backend of this call.